@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Convert notes and chords to Roman numeral notation
 
-our $VERSION = '0.1104';
+our $VERSION = '0.1105';
 
 use List::MoreUtils qw/ any first_index /;
 use Moo;
@@ -280,7 +280,7 @@ Music::ToRoman - Convert notes and chords to Roman numeral notation
 
 =head1 VERSION
 
-version 0.1104
+version 0.1105
 
 =head1 SYNOPSIS
 
@@ -391,6 +391,7 @@ Show the progress of the B<parse> method.  Default C<0>
     scale_note  => $note,
     scale_name  => $name,
     major_tonic => $tonic,
+    chords      => $chords,
     verbose     => $verbose,
   );
 
@@ -433,7 +434,7 @@ L<Music::Scales>
 
 L<https://en.wikipedia.org/wiki/Roman_numeral_analysis>
 
-For example usage, check out the test files F<t/*> in this
+For example usage, check out the test files F<t/*-methods.t> in this
 distribution.  Also see F<eg/roman> and F<eg/basslines> in
 L<Music::BachChoralHarmony>.
 
